durationtools.duration_tokens_to_duration_pairs_with_least_common_denominator
=============================================================================

.. autofunction:: abjad.tools.durationtools.duration_tokens_to_duration_pairs_with_least_common_denominator.duration_tokens_to_duration_pairs_with_least_common_denominator
